@@ -1,4 +1,5 @@
 import threading
+import multiprocessing
 from typing import Callable
 
 from loguru import logger
@@ -30,6 +31,16 @@ class BaseCommand:
         return self._command
 
 
+class ThreadedCommand(BaseCommand):
+    def launch(self):
+        threading.Thread(target=self._command, daemon=True).start()
+
+
+class MultiprocessingCommand(BaseCommand):
+    def launch(self):
+        multiprocessing.Process(target=self._command, daemon=True).start()
+
+
 class FunctionCommand(BaseCommand):
     def __init__(self, func: Callable) -> None:
         super().__init__()
